==> apache-streampipes-0.90.0-source-release.zip: apache-streampipes-0.90.0/streampipes-resource-management/src/main/java/org/apache/streampipes/resource/management/DataProcessorResourceManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.resource.management;

import org.apache.streampipes.model.graph.DataProcessorDescription;
import org.apache.streampipes.model.graph.DataProcessorInvocation;
import org.apache.streampipes.storage.api.IDataProcessorStorage;
import org.apache.streampipes.storage.management.StorageDispatcher;

public class DataProcessorResourceManager extends AbstractPipelineElementResourceManager<IDataProcessorStorage, DataProcessorDescription, DataProcessorInvocation> {

  public DataProcessorResourceManager() {
    super(StorageDispatcher.INSTANCE.getNoSqlStore().getDataProcessorStorage());
  }

  @Override
  protected DataProcessorInvocation toInvocation(DataProcessorDescription description) {
    return new DataProcessorInvocation(description);
  }
}

==> apache-streampipes-0.98.0-source-release.zip: apache-streampipes-0.98.0/streampipes-resource-management/src/main/java/org/apache/streampipes/resource/management/DataProcessorResourceManager.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */
package org.apache.streampipes.resource.management;

import org.apache.streampipes.model.graph.DataProcessorDescription;
import org.apache.streampipes.model.graph.DataProcessorInvocation;
import org.apache.streampipes.storage.api.IDataProcessorStorage;
import org.apache.streampipes.storage.management.StorageDispatcher;

public class DataProcessorResourceManager extends
    AbstractPipelineElementResourceManager<IDataProcessorStorage, DataProcessorDescription, DataProcessorInvocation> {

  public DataProcessorResourceManager() {
    super(StorageDispatcher.INSTANCE.getNoSqlStore().getDataProcessorStorage());
  }

  @Override
  protected DataProcessorInvocation toInvocation(DataProcessorDescription description) {
    return new DataProcessorInvocation(description);
  }
}
